@@ -721,7 +721,7 @@ int process_cgivars(void) {
 
 	variables = getcgivars();
 
-	for(x = 0; variables[x] != NULL; x++) {
+	for(x = 0; variables[x]; x++) {
 
 		/* do some basic length checking on the variable identifier to prevent buffer overflows */
 		if(strlen(variables[x]) >= MAX_INPUT_BUFFER - 1) {
@@ -1785,7 +1785,7 @@ void display_recent_alerts(void) {
 
 		printf("<td CLASS='data%s'>%s</td>", bgclass, (temp_event->state_type == AE_SOFT_STATE) ? "SOFT" : "HARD");
 
-		printf("<td CLASS='data%s'>%s</td>", bgclass, temp_event->event_info);
+		printf("<td CLASS='data%s'>%s</td>", bgclass, html_encode(temp_event->event_info, 1));
 
 		printf("</tr>\n");
 		}
