@@ -1,8 +1,8 @@
 <?php
 include_once(dirname(__FILE__).'/includes/utils.inc.php');
 
-$this_version = '4.4.7';
-$this_year = '2022';
+$this_version = '4.4.14';
+$this_year = '2023';
 ?>
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
 
@@ -145,7 +145,7 @@ $this_year = '2022';
 <div id="currentversioninfo">
 	<div class="product">Nagios<sup><span style="font-size: small;">&reg;</span></sup> Core<sup><span style="font-size: small;">&trade;</span></sup></div>
 	<div class="version">Version <?php echo $this_version; ?></div>
-	<div class="releasedate">April 14, 2022</div>
+	<div class="releasedate">August 01, 2023</div>
 	<div class="checkforupdates"><a href="https://www.nagios.org/checkforupdates/?version=<?php echo $this_version; ?>&amp;product=nagioscore" target="_blank">Check for updates</a></div>
 </div>
 
@@ -198,6 +198,10 @@ $this_year = '2022';
 			</ul>
 		</div>
 
+
+		<div id="splashbox3" class="splashbox3-empty"><!-- youtube playlist -->
+		</div>
+
 		<div id="splashbox2" class="splashbox">
 			<h2>Quick Links</h2>
 			<ul>
@@ -210,8 +214,7 @@ $this_year = '2022';
 			</ul>
 		</div>
 
-		<div id="splashbox3" class="splashbox3-empty"><!-- youtube playlist -->
-		</div>
+	
 
 	</div><!-- end splashrow1 -->
 
